OpenWorkflow Documentation
###########################

OpenWorkflow is a suite of development tools to facilitate the creation and
implemention of `Wearable Cognitive Assistants (WCA)`_. They key idea of
OpenWorkflow is to represent WCA application logic as finite state machines (FSM). You
can read more about the fast prototyping methodology of OpenWorkflow in
`this document (Section 6.2) <https://junjuew.github.io/assets/thesis.pdf>`_.

OpenWorkflow provides the following tools.

* gabrieltool: A Python library to create and persist finite state machine based wearable cognitive assistants.
* Finite State Machine (FSM) Web Editor: A browser-based GUI to view and edit state machines.

User Guide
**********************

.. toctree::
   :maxdepth: 1

   installation
   quickstart
   tutorial
   source/modules
   contributing
   history

.. include:: installation.rst
.. include:: quickstart.rst

Contribute
**********************

- Issue Tracker: `<https://www.github.com/cmusatyalab/OpenWorkflow/issues>`_
- Source Code: `<https://www.github.com/cmusatyalab/OpenWorkflow>`_

Indices and tables
**********************
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _`Wearable Cognitive Assistants (WCA)`: https://junjuew.github.io/assets/thesis.pdf
.. `Prototyping Methodology`_: 